( cd usr/lib64 ; rm -rf libraw1394.so.11 )
( cd usr/lib64 ; ln -sf libraw1394.so.11.0.0 libraw1394.so.11 )
( cd usr/lib64 ; rm -rf libraw1394.so )
( cd usr/lib64 ; ln -sf libraw1394.so.11.0.0 libraw1394.so )
